--
-- Selected TOC Entries:
--
--
-- Data for TOC Entry ID 1 (OID 1943006)
--
-- Name: driver Type: TABLE DATA Owner: aliphe
--


INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('CSV','FTP','CSV driver',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('CSV','HTTP','CSV driver',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('CSV','HTTPS','CSV driver',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('CSV','LFS','CSV driver',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('CSV','POP3','CSV driver',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('CSV','SMTP','CSV driver',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XML','FTP','Simple XML files',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XML','HTTP','Simple XML files',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XML','HTTPS','Simple XML files',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XML','LFS','Simple XML files',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XML','POP3','Simple XML files',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XML','SMTP','Simple XML files',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XMLd','FTP','XML DOM filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XMLd','HTTP','XML DOM filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XMLd','HTTPS','XML DOM filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XMLd','LFS','XML DOM filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XMLd','POP3','XML DOM filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XMLd','SMTP','XML DOM filter',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HTML','FTP','Simple HTML Table',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HTML','HTTP','Simple HTML Table',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HTML','HTTPS','Simple HTML Table',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HTML','LFS','Simple HTML Table',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HTML','POP3','Simple HTML Table',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HTML','SMTP','Simple HTML Table',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HTMLd','FTP','HTML DOM filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HTMLd','HTTP','HTML DOM filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HTMLd','HTTPS','HTML DOM filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HTMLd','LFS','HTML DOM filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HTMLd','POP3','HTML DOM filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HTMLd','SMTP','HTML DOM filter',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FLR','FTP','FFL files',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FLR','HTTP','FFL files',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FLR','HTTPS','FFL files',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FLR','LFS','FFL files',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FLR','POP3','FFL files',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FLR','SMTP','FFL files',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XCEL','FTP','Simple Excel Sheet driver',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XCEL','HTTP','Simple Excel Sheet driver',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XCEL','HTTPS','Simple Excel Sheet driver',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XCEL','LFS','Simple Excel Sheet driver',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XCEL','POP3','Simple Excel Sheet driver',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('XCEL','SMTP','Simple Excel Sheet driver',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FT','FTP','No filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FT','HTTP','No filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FT','HTTPS','No filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FT','LFS','No filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FT','POP3','No filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FT','SMTP','No filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('REC','FTP','COBOL like record files',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('REC','HTTP','COBOL like record files',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('REC','HTTPS','COBOL like record files',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('REC','LFS','COBOL like record files',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('REC','POP3','COBOL like record files',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('REC','SMTP','COBOL like record files',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FLTR','FTP','User filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FLTR','HTTP','User filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FLTR','HTTPS','User filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FLTR','LFS','User filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FLTR','POP3','User filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('FLTR','SMTP','User filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('bFLTR','FTP','User binary filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('bFLTR','HTTP','User binary filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('bFLTR','HTTPS','User binary filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('bFLTR','LFS','User binary filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('bFLTR','POP3','User binary filter',NULL);
-- INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('bFLTR','SMTP','User binary filter',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('LDAPD','LDAP','Simple LDAP driver',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('mySql','DBI','mySql driver',NULL);
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('Oracle','DBI','Oracle driver','yes');
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('Pg','DBI','Postgress Driver','yes');
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('Generic','DBI','Generic DBI Driver','yes');
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('DIRSL','FTP','Directory listing','');
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('DIRSL','LFS','Directory listing','');
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HPRIM','FTP','HPRIM Driver','');
INSERT INTO "driver" ("driverid","protocolid","driverlabel","cantransact") VALUES ('HPRIM','LFS','HPRIM Driver','');
